==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/tripcore/TRIPMsgParser.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */
static const char* const TRIPMsgParser_cxx_Version = 
"$Id: TRIPMsgParser.cxx,v 1.4 2000/11/13 19:38:55 surendra Exp $";
#include <assert.h>

#include "TRIPMsgParser.hxx"
#include "TRIPOpenMsg.hxx"
#include "TRIPUpdateMsg.hxx"
#include "TRIPNotificationMsg.hxx"
#include "TRIPKeepAliveMsg.hxx"
#include "cpLog.h"


Sptr<TRIPMsg>
TRIPMsgParser::parse(const char* data) throw (TRIPBadDataException&)
{
    TRIPHeader hdr(data);
    return(parse(hdr, data+3));
}

Sptr<TRIPMsg>
TRIPMsgParser::parse(const TRIPHeader& hdr, const char* data) throw (TRIPBadDataException&)
{
    Sptr<TRIPMsg> tripMsg = 0;
    TRIPOpCode cCode = static_cast<TRIPOpCode>(hdr.getType());
    switch(cCode)
    {
        case TRIP_OP_OPEN:
        {
            cpLog(LOG_DEBUG, "Creating OPEN msg");
            tripMsg = new TRIPOpenMsg();
            tripMsg->parse(hdr, data);
        }
        break;
        case TRIP_OP_UPDATE:
        {
            cpLog(LOG_DEBUG, "Creating Update msg");
            tripMsg = new TRIPUpdateMsg();
            tripMsg->parse(hdr, data);
        }
        break;
        case TRIP_OP_NOTIF:
        {
            cpLog(LOG_DEBUG, "Creating Notification msg");
            tripMsg = new TRIPNotificationMsg();
            tripMsg->parse(hdr, data);
        }
        break;
        case TRIP_OP_KEEPALIVE:
        {
            cpLog(LOG_DEBUG, "Creating KeepAlive msg");
            tripMsg = new TRIPKeepAliveMsg();
            tripMsg->parse(hdr, data);
        }
        break;
        default:
            cpLog(LOG_DEBUG, "Unknown message type");
            throw TRIPBadDataException("Unknown message type",
                                       __FILE__, __LINE__, 0);
        break;
    }
    return tripMsg;
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/tripcore/TRIPMsgParser.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */
static const char* const TRIPMsgParser_cxx_Version = 
"$Id: TRIPMsgParser.cxx,v 1.7 2001/03/05 20:21:19 kevinmc Exp $";
#include <assert.h>

#include "TRIPMsgParser.hxx"
#include "TRIPOpenMsg.hxx"
#include "TRIPUpdateMsg.hxx"
#include "TRIPNotificationMsg.hxx"
#include "TRIPKeepAliveMsg.hxx"
#include "TRIPErrorHandler.hxx"
#include "cpLog.h"


Sptr<TRIPMsg>
TRIPMsgParser::parse(const char* data) throw (TRIPBadDataException&)
{
    TRIPHeader hdr(data);
    return(parse(hdr, data+hdr.getHdrLength()));
}

Sptr<TRIPMsg>
TRIPMsgParser::parse(const TRIPHeader& hdr, const char* data) throw (TRIPBadDataException&)
{
    Sptr<TRIPMsg> tripMsg = 0;
    TRIPOpCode cCode = static_cast<TRIPOpCode>(hdr.getType());
    switch(cCode)
    {
        case TRIP_OP_OPEN:
        {
            cpLog(LOG_DEBUG, "Creating OPEN msg");
            tripMsg = new TRIPOpenMsg();
            tripMsg->parse(hdr, data);
        }
        break;
        case TRIP_OP_UPDATE:
        {
            cpLog(LOG_DEBUG, "Creating Update msg");
            tripMsg = new TRIPUpdateMsg();
            tripMsg->parse(hdr, data);
        }
        break;
        case TRIP_OP_NOTIF:
        {
            cpLog(LOG_DEBUG, "Creating Notification msg");
            tripMsg = new TRIPNotificationMsg();
            tripMsg->parse(hdr, data);
        }
        break;
        case TRIP_OP_KEEPALIVE:
        {
            cpLog(LOG_DEBUG, "Creating KeepAlive msg");
            tripMsg = new TRIPKeepAliveMsg();
            tripMsg->parse(hdr, data);
        }
        break;
        default:
            throw TRIPBadDataException("Undefined message type",
                    __FILE__, __LINE__, TRIP_ERR_MSG_HEADER, H_BAD_MSG_TYPE);
        break;
    }
    return tripMsg;
}
